@@ -6,7 +6,7 @@ our %config;
 
 sub patch_data {
     return {
-        v => 2,
+        v => 3,
         config => {
             -v1 => {default=>10},
             -v2 => {},
@@ -18,6 +18,11 @@ sub patch_data {
                 sub_name => 'foo',
                 code => sub { "foo from p1" },
             },
+            {
+                action => 'add',
+                sub_name => 'baz',
+                code => sub { "baz from p1" },
+            },
         ],
     };
 }
